Justify

Enum Justify 

pub enum Justify {
    Start,
    SpaceBetween,
}
How a container places children when its assigned rect is larger than the children’s resolved sizes plus the minimum gap.

Variants



Start

Pack children at the start of the primary axis.



SpaceBetween

Add all surplus cells to the gaps between children, keeping the first child at the start and the last child at the end.